@@ -1,10 +1,7 @@
 from __future__ import print_function
 
 import sys
-from distutils.version import StrictVersion # pylint: disable=E0611
-from optparse import make_option
 
-from django import get_version, VERSION
 from django.core.management.base import BaseCommand
 
 from chroniker.models import get_current_job
@@ -13,28 +10,11 @@ from chroniker.models import get_current_job
 class Command(BaseCommand):
     help = 'Runs a specific monitoring routine.'
 
-    option_list = getattr(BaseCommand, 'option_list', ()) + (
-        make_option('--imports', dest='imports', help='Modules to import.'),
-        make_option('--query', dest='query', help='The query to run.'),
-        make_option('--verbose', dest='verbose', default=False, help='If given, displays extra logging messages.'),
-    )
-
-    def create_parser(self, prog_name, subcommand):
-        """
-        For ``Django>=1.10``
-        Create and return the ``ArgumentParser`` which extends ``BaseCommand`` parser with
-        chroniker extra args and will be used to parse the arguments to this command.
-        """
-        parser = super(Command, self).create_parser(prog_name, subcommand)
-        version_threshold = StrictVersion('1.10')
-        current_version = StrictVersion(get_version(VERSION))
-        if current_version >= version_threshold:
-            parser.add_argument('args', nargs="*")
-            parser.add_argument('--imports', dest='imports', help='Modules to import.')
-            parser.add_argument('--query', dest='query', help='The query to run.')
-            parser.add_argument('--verbose', dest='verbose', default=False, help='If given, displays extra logging messages.')
-            self.add_arguments(parser)
-        return parser
+    def add_arguments(self, parser):
+        parser.add_argument('args', nargs="*")
+        parser.add_argument('--imports', dest='imports', help='Modules to import.')
+        parser.add_argument('--query', dest='query', help='The query to run.')
+        parser.add_argument('--verbose', dest='verbose', default=False, help='If given, displays extra logging messages.')
 
     def handle(self, *args, **options):
         imports = options['imports']
