@@ -1,4 +1,5 @@
 from __future__ import print_function
+import html
 import errno
 import os
 import signal
@@ -78,8 +79,7 @@ class TeeFile(StringIO):
     """
 
     def __init__(self, file, auto_flush=False, queue=None, local=True): # pylint: disable=W0622
-        super(TeeFile, self).__init__()
-        #StringIO.__init__(self)
+        super().__init__()
         self.file = file
         self.auto_flush = auto_flush
         self.length = 0
@@ -275,9 +275,12 @@ class TimedProcess(Process):
     daemon = True
 
     def __init__(self, max_seconds, time_type=c.MAX_TIME, fout=None, check_freq=1, *args, **kwargs):
-        super(TimedProcess, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fout = fout or sys.stdout
-        self.t0 = time.clock()
+        try:
+            self.t0 = time.process_time()
+        except AttributeError:
+            self.t0 = time.clock()
         self.t0_objective = time.time()
         self.max_seconds = float(max_seconds)
         self.t1 = None
@@ -332,7 +335,13 @@ class TimedProcess(Process):
     def get_duration_seconds_cpu(self):
         if self.t1 is not None:
             return self.t1 - self.t0
-        return time.clock() - self.t0
+
+        try:
+            now = time.process_time()
+        except AttributeError:
+            now = time.clock()
+
+        return now - self.t0
 
     def get_duration_seconds_cpu_recursive(self):
         # Note, this calculation will consume much user
@@ -419,7 +428,7 @@ class TimedProcess(Process):
         return max(self.max_seconds - self.get_duration_seconds(), 0)
 
     def start(self, *args, **kwargs):
-        super(TimedProcess, self).start(*args, **kwargs)
+        super().start(*args, **kwargs)
         self._p = psutil.Process(self.pid)
 
     def start_then_kill(self, verbose=True):
@@ -443,7 +452,10 @@ class TimedProcess(Process):
                     print('\nAttempting to terminate expired process %s...' % (self.pid,), file=self.fout)
                 timeout = True
                 self.terminate()
-        self.t1 = time.clock()
+        try:
+            self.t0 = time.process_time()
+        except AttributeError:
+            self.t0 = time.clock()
         self.t1_objective = time.time()
         return timeout
 
@@ -492,17 +504,17 @@ def import_string(dotted_path):
 
     try:
         module_path, class_name = dotted_path.rsplit('.', 1)
-    except ValueError:
+    except ValueError as exc:
         msg = "%s doesn't look like a module path" % dotted_path
-        raise ImportError(msg)
+        raise ImportError(msg) from exc
 
     module = import_module(module_path)
 
     try:
         return getattr(module, class_name)
-    except AttributeError:
+    except AttributeError as exc:
         msg = 'Module "%s" does not define a "%s" attribute/class' % (dotted_path, class_name)
-        raise ImportError(msg)
+        raise ImportError(msg) from exc
 
 
 def smart_print(*args, **kwargs):
@@ -525,6 +537,7 @@ def clean_samples(result):
     max_l = 10000
     if len(result) > max_l * 3:
         result = result[:max_l] + '\n...\n' + result[-max_l:]
+    result = html.escape(result)
     result = result.replace('{', '  &#123;')
     result = result.replace('}', '&#125;')
     result = result.replace('\n', '<br/>')
